@@ -24,7 +24,15 @@ def xapi_set(xapi, set_list):
 
 def xapi_get(xapi, xpath):
     try:
-        xapi.set(xpath=xpath)
+        xapi.get(xpath=xpath)
+    except pan.xapi.PanXapiError as PE:
+        print(PE)
+        sys.exit(1)
+
+
+def xapi_show(xapi, xpath):
+    try:
+        xapi.show(xpath=xpath)
     except pan.xapi.PanXapiError as PE:
         print(PE)
         sys.exit(1)
